@@ -1,4 +1,5 @@
 import time
+import datetime
 import requests
 import os
 import json
@@ -53,7 +54,11 @@ class Power:
         values = {host:[] for host in host_list}
         for elements in raws:
             device_id = elements['device_id']
-            timestamps[device_id].append(int(datetime.datetime.strptime(elements['timestamp'], "%Y-%m-%dT%H:%M:%S%z").timestamp()))
+            try:
+                timestamps[device_id].append(int(datetime.datetime.strptime(elements['timestamp'], "%Y-%m-%dT%H:%M:%S%z").timestamp()))
+            except:
+                timestamps[device_id].append(int(datetime.datetime.strptime(elements['timestamp'], "%Y-%m-%dT%H:%M:%S.%f%z").timestamp()))
+
             values[device_id].append(elements['value'])
         result = [(host, timestamps[host], values[host]) for host in host_list]
 
